@@ -2,15 +2,9 @@ from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth.models import User
 from django.contrib.gis.admin import OSMGeoAdmin
-from rgd.models import ChecksumFile, SpatialAsset, WhitelistedEmail
+from rgd.models import SpatialAsset, WhitelistedEmail
 
-from .mixins import (
-    MODIFIABLE_FILTERS,
-    TASK_EVENT_FILTERS,
-    TASK_EVENT_READONLY,
-    _FileGetNameMixin,
-    reprocess,
-)
+from .mixins import MODIFIABLE_FILTERS, _FileGetNameMixin
 
 
 def make_users_active(modeladmin, request, queryset):
@@ -55,33 +49,6 @@ class WhitelistedEmailAdmin(OSMGeoAdmin):
     )
 
 
-@admin.register(ChecksumFile)
-class ChecksumFileAdmin(OSMGeoAdmin):
-    list_display = (
-        'pk',
-        'name',
-        'status',
-        'modified',
-        'created',
-        'type',
-        'data_link',
-        'collection',
-    )
-    readonly_fields = (
-        'checksum',
-        'last_validation',
-    ) + TASK_EVENT_READONLY
-    actions = (reprocess,)
-    list_filter = (
-        MODIFIABLE_FILTERS
-        + TASK_EVENT_FILTERS
-        + (
-            'type',
-            'collection',
-        )
-    )
-
-
 @admin.register(SpatialAsset)
 class SpatialAssetAdmin(OSMGeoAdmin, _FileGetNameMixin):
     list_display = (
